#! /bin/ksh

# -----------------------------------------------------------------------
# Reports whether MEPs exist for given IP address
#
# @param
#	user=<DS user>
#	password=<DS password>
#	ipaddress=<ip of mep>
#
# @return
#	result=success
#			At least one MEP exists in Systems Director
#
#	result=notfound
#			In case no MEP(s) found in Systems Director
#
#	result=fail_auth
#			Failed to invoke smcli with DS credentials supplied.
#
#	result=fail
#		In case general error occurred when attempting to check whether the
#		MEP(s) exists.
#
# ------------------------------------------------------------------------

user="$(echo $1 | awk '{ {split($1, split_result, "=")} {print split_result[2]} }')"
password="$(echo $2 | awk '{ {split($1, split_result, "=")} {print split_result[2]} }')"
ipaddress="$(echo $3 | awk '{ {split($1, split_result, "=")} {print split_result[2]} }')"

smcli -user $user -pw $password lssys -i $ipaddress > /dev/null 2>&1
RC=$?

if [ "$RC" = "3" ]; then
        echo "result=fail_auth"
        exit 0;
fi

if [ "$RC" = "20" ]; then
        echo "result=notfound"
        exit 0;
fi

if [ "$RC" != "0" ]; then
        echo "result=fail"
        exit 0;
fi

echo "result=success"
