#!/usr/bin/ksh

# -----------------------------------------------------------------------
# Checks whether the given port is in a listening state using netstat
#
# @param
#	prot=<udp|tcp>
#	port=<port number>
#
# @return
#	result=fail
#			In case netstat execution failed (either not found or simply 
#			failed)
#
#	result=success,port_RC={success, fail}
#			The evaluation was successfull. port_RC set to successful if 
#			port is being listened, fail otherwise
#
# ------------------------------------------------------------------------

prot="$(echo $1 | awk '{ {split($1, split_result, "=")} {print split_result[2]} }')"
port="$(echo $2 | awk '{ {split($1, split_result, "=")} {print split_result[2]} }')"

# -----------------------------------------------------------------------
# At first just check that netstat works (i/o redirect -- we do not
# want to see its output
# -------------------------------------------------------------------------
netstat -na > /dev/null 2>&1
RC=$?

# ----------------------------------------
# If netstat by itself produced some error
# then fail the entire script with result=fail
# but still exit with 0. PD flow will ask the
# user to check manually
# ----------------------------------------
if [ "$RC" != "0" ]; then
	echo "result=fail"
	exit 0;
fi

if [ "$prot" = "udp" ]; then
	netstat -na | grep udp | grep -w $port >/dev/null 2>&1
	RC=$?
	if [ "$RC" != "0" ]; then
		echo "result=success,port_RC=fail"
		exit 0
	fi
	echo "result=success,port_RC=success"
	exit 0
fi

if [ "$prot" = "tcp" ]; then

	output="$(netstat -na | grep -w $port | grep -w LISTEN)"
	output_no_spaces=`echo $output | sed -e 's/^ *//' -e 's/ *$//'`

	# --------------------------------------------------
	# Process the output from netstat command
	# --------------------------------------------------
	
	case "$output_no_spaces" in
    	*LISTEN* ) echo "result=success,port_RC=success"; exit 0;;
    	* ) echo "result=success,port_RC=fail";;
	esac

fi
