#!/usr/bin/ksh

# --------------------------------------------------------------------------
# Resets UID and Tivoli GUID keys on the endpoint.
#
# @return
#	result=success
#			Overall operation succeed.
#
#	result=fail
#			Overall operation failed. More details given in ssh_RC below.
#
#	uid_RC=key_gen_fail
#			A failure occurred while re-generating UID key
#
#	tivguid_RC=key_gen_fail
#			A failure occurred while re-generating Tivoli GUID key
#
# ---------------------------------------------------------------------------


# -----------------------------------------------
# Generate new UID
# -----------------------------------------------
if [ -f /etc/ibm/director/twgagent/twgagent.uid ];then
	/usr/bin/rm -f /etc/ibm/director/twgagent/twgagent.uid
fi

if [ -x  /opt/ibm/director/bin/genuid ];then
	 /opt/ibm/director/bin/genuid >/dev/null 2>&1
	RC=$?
	if [ "$RC" != "0" ]; then
		echo "result=fail,uid_RC=key_gen_fail"
		exit 0
	fi
fi

# -----------------------------------------------
# Generate new tivguid
# -----------------------------------------------
if [ -x /usr/tivoli/guid/tivguid ];then
	LANG=C;
	/usr/tivoli/guid/tivguid  -Write -New >/dev/null 2>&1
	RC=$?
	if [ "$RC" != "0" ]; then
		echo "result=fail,tivguid_RC=key_gen_fail"
		exit 0
	fi
	
fi

echo "result=success"
