#!/usr/bin/ksh

# -----------------------------------------------------------------------
# Register / unregister dummy SLP service (service:ddf_dummy) against 
# endpoint SLP SA
# 
# @param
#	ipaddress=<host ip>
#				The IP address of the host to register/unregister the dummy SLP on
#	operation=<register | unregister>
#				The operation: register or unregister
#
# @return
#	result=notfound
#			No SLP registration utility found.
#
#	result=fail
#			SLP registration / de-registration fail
#
#	result=success
#			SLP registration completed successfully
#
# ------------------------------------------------------------------------

ipaddress="$(echo $1 | awk '{ {split($1, split_result, "=")} {print split_result[2]} }')"
operation="$(echo $2 | awk '{ {split($1, split_result, "=")} {print split_result[2]} }')"

if [ -e /usr/sbin/slp_srvreg ]; then
	slp_reg_tool="/usr/sbin/slp_srvreg"
fi

if [ $slp_reg_tool"X" = "X" ]; then
	echo "result=notfound"
	exit 0;
fi

if [ "$operation" = "register" ]; then
	# Lifetime set to 5 minutes
	$slp_reg_tool -a "description=It is for DDF test" -l 300 -u "service:ddf_dummy://$ipaddress" -t service:ddf_dummy >/dev/null 2>&1
	RC=$?
	if [ "$RC" = "0" ]; then
		echo "result=success"
	else
		echo "result=fail"
	fi
fi

if [ "$operation" = "unregister" ]; then
	$slp_reg_tool -d "service:ddf_dummy://$ipaddress" >/dev/null 2>&1
	
	RC=$?
	if [ "$RC" = "0" ]; then
		echo "result=success"
	else
		echo "result=fail"
	fi
fi

exit 0
