#! /bin/bash

# --------------------------------------------------------------------------
# Resets SSH keys on the endpoint.
#
# @return
#	result=success
#			Overall operation succeed.
#
#	result=fail
#			Overall operation failed. More details given in ssh_RC below.
#
#	ssh_RC={notfound, key_gen_fail, start_fail}
#
#	ssh_RC=notfound
#			The service command was not found on this endpoint
#
#	ssh_RC=key_gen_fail
#			A failure occurred while re-generating SSH keys
#
#	ssh_RC=start_fail
#			A failure occurred when starting the service
#
# ---------------------------------------------------------------------------

# -----------------------------------------------
# Fail if can not locate the service 
# -----------------------------------------------
if [ ! -e /etc/init.d/sshd ]; then
	echo "result=fail,ssh_RC=notfound"
	exit 0
fi

# -----------------------------------------------
# Stop the service in any case. Don't check RC
# -----------------------------------------------
/etc/init.d/sshd stop > /dev/null 2>&1

# -----------------------------------------------
# Remove the keys
# -----------------------------------------------
/bin/rm -f /etc/ssh/ssh_host_key
/bin/rm -f /etc/ssh/ssh_host_rsa_key
/bin/rm -f /etc/ssh/ssh_host_dsa_key

# -----------------------------------------------
# Regenerate the keys
# -----------------------------------------------
/usr/bin/ssh-keygen -f /etc/ssh/ssh_host_key -N '' -t rsa1 > /dev/null 2>&1
RC=$?
if [ "$RC" != "0" ]; then
	echo "result=fail,ssh_RC=key_gen_fail"
	/etc/init.d/sshd start > /dev/null 2>&1
	exit 0
fi

/usr/bin/ssh-keygen -f /etc/ssh/ssh_host_rsa_key -N '' -t rsa > /dev/null 2>&1
RC=$?
if [ "$RC" != "0" ]; then
	echo "result=fail,ssh_RC=key_gen_fail"
	/etc/init.d/sshd start > /dev/null 2>&1
	exit 0
fi

/usr/bin/ssh-keygen -f /etc/ssh/ssh_host_dsa_key -N '' -t dsa > /dev/null 2>&1
RC=$?
if [ "$RC" != "0" ]; then
	echo "result=fail,ssh_RC=key_gen_fail"
	/etc/init.d/sshd start > /dev/null 2>&1
	exit 0
fi

# -----------------------------------------------
# Start the service
# -----------------------------------------------
/etc/init.d/sshd start > /dev/null 2>&1
RC=$?
if [ "$RC" != "0" ]; then
	echo "result=fail,ssh_RC=start_fail"
	exit 0
fi

echo "result=success"
