@echo off
rem --------------------------------------------------------------------------
rem Retrieves Tivoli GUID key from the endpoint.
rem
rem @return
rem	result=success
rem			Overall operation succeed. Additional info might be 
rem			set in key.
rem
rem	result=fail
rem			Overall operation failed.
rem
rem
rem	tivoli_guid={<tivoli_guid>, notfound}
rem			The key. 
rem			notfound in case key not found
rem
rem ---------------------------------------------------------------------------

rem -----------------------------------------------
rem Do we indeed have a tivoli guid utility to use?
rem -----------------------------------------------

set tivoliGuidExe="C:\Program Files\Tivoli\guid\tivguid.exe"

if not exist %tivoliGuidExe% set tivoliGuidExe="C:\Program Files (x86)\Tivoli\guid\tivguid.exe"

if not exist %tivoliGuidExe% goto FINAL

rem -----------------------------------------------
rem Sanity check to verify the command itself
rem works
rem -----------------------------------------------
call %tivoliGuidExe% -Show >NUL 2>NUL
if %errorlevel% neq 0 (
	echo result=fail
	exit /b 0
)

rem -----------------------------------------------
rem Note: Despite the fact that the command outputs
rem stderr, it still produces good data to collect.
rem Thus we redirect stederr to NUL to get rid of
rem it and only parse what we need: stdout
rem -----------------------------------------------
for /f "tokens=1,2,3,4,5,6,7,8,9,10,11,12,13,14,15,16,17 delims=:." %%a in ('%tivoliGuidExe% -Show 2^> NUL') do (
	
	rem ----------------------------------------------------
	rem %%a is the first token of each line
	rem However, we are interested in lines beginning with
	rem 'Guid'
	rem ----------------------------------------------------
	if "%%a"=="Guid" (
	
	echo result=success,tivoli_guid=%%b%%c%%d%%e%%f%%g%%h%%i%%j%%k%%l%%m%%n%%o%%p%%q
	exit /b 0	
	)
)

:FINAL
echo result=success,tivoli_guid=notfound
exit /b 0
