@echo off

rem -----------------------------------------------------------------------
rem Retrieves the access state of the MEP.
rem
rem @param
rem user=<DS user>
rem password=<DS password>
rem	ipaddress=<ip of mep>
rem	type=<MEP type>
rem
rem @return
rem	result=success
rem			Overall operation succeed
rem	
rem	state=<access state>
rem			Valid for a success result. Indicates the access state of 
rem			the MEP
rem
rem	result=notfound
rem			In case ME was not found in Systems Director
rem
rem	result=fail_retrieve
rem		In case error occurred when attempting to retrieve the MEP
rem		from Systems Director
rem
rem result=fail_auth
rem		Failed to invoke smcli with DS credentials supplied.
rem
rem	result=fail
rem		In case general error occurred when attempting to retrieve the
rem		access state of the MEP.
rem
rem ------------------------------------------------------------------------


rem ---------------------------------------------------------
rem Seems that '=' performs already as a delimeter between 
rem arguments passed
rem ---------------------------------------------------------

set user=%2
set password=%4
set ipaddress=%6
set mep_type=%8

rem ------------------------------------------------------------------------
rem At first just check that command works (i/o redirect -- we do not
rem want to see its output)
rem -------------------------------------------------------------------------

smcli -user %user% -pw %password% lssys -t %mep_type% -i %ipaddress% -A AccessState  >NUL 2>NUL

if %ERRORLEVEL% equ 20 (
        echo result=notfound
        exit /b 0
)

if %ERRORLEVEL% equ 3 (
        echo result=fail_auth
        exit /b 0
)

if errorlevel 1 (
        echo result=fail_retrieve
        exit /b 0
)

rem Trying again
rem -------------------------------------------------------------------------
rem Due to a bug in smcli lssys it can return RC=0 but without any data
rem (empty line)
rem -------------------------------------------------------------------------
for /f "tokens=*" %%a in ('smcli -user %user% -pw %password% lssys -t %mep_type% -i %ipaddress% -A AccessState') do (
    GOTO CONTINUE
)

echo result=notfound
exit /b 0

:CONTINUE
for /f "tokens=2 delims=:" %%a in ('smcli -user %user% -pw %password% lssys -t %mep_type% -i %ipaddress% -A AccessState') do (
    set state=%%a
)

rem -----------------------------------------------------------------------
rem Extract leading space resulted from previous command output
rem -------------------------------------------------------------------------

for /f "tokens=1 delims= " %%a in ("%state%") do set state_no_space=%%a

echo result=success,state=%state_no_space%
