@echo off

rem -----------------------------------------------------------------------
rem Checks whether the given port is in a listening state using netstat
rem
rem @param prot=<udp|tcp>
rem	@param port=<port number>
rem
rem @return
rem	result=fail
rem			In case netstat execution failed (either not found or simply
rem			failed)
rem
rem	result=success,port_RC={success, fail}
rem			The evaluation was successfull. port_RC set to successful if
rem			port is being listened, fail otherwise
rem
rem ------------------------------------------------------------------------

set prot=%2
set port=%4

rem -------------------------------------------------------------------------
rem At first just check that netstat works (i/o redirect -- we do not
rem want to see its output
rem -------------------------------------------------------------------------
call netstat -na >NUL 2>NUL

rem -----------------------------------------------
rem If netstat by itself produced some error
rem then fail the entire script with result=fail
rem but still exit with 0. PD flow will ask the
rem user to check manually
rem -----------------------------------------------

if ERRORLEVEL 1 (
	echo result=fail
	exit /b 0
)

if "%prot%"=="udp" (

	rem --------------------------------------------------------------------------
	rem We assume that netstat outputs 4 columns when delimiting using space.
	rem Protocol, Local Address, Foreign Address and State.
	rem %%a denotes the Protocol.
	rem ---------------------------------------------------------------------------
	for /f "tokens=1 delims= " %%a in ('netstat -na ^|find ":%port% "') do (
	
		rem ----------------------------------------------------
		rem <TOKEN1> Protocol
		rem ----------------------------------------------------
		if "%%a"=="UDP" goto UDP_LISTENING_LABEL
	)
	
	rem ---------------------------------------
	rem if here then we did not find UDP port
	rem ---------------------------------------
	echo result=success,port_RC=fail
	exit /b 0

:UDP_LISTENING_LABEL
	echo result=success,port_RC=success
	exit /b 0
)

if "%prot%"=="tcp" (

	rem --------------------------------------------------------------------------
	rem We assume that netstat outputs 4 columns when delimiting using space.
	rem Protocol, Local Address, Foreign Address and State.
	rem %%b denotes the State.
	rem ---------------------------------------------------------------------------
	for /f "tokens=2,4 delims= " %%a in ('netstat -na ^|find ":%port% "') do (
	
		rem ----------------------------------------------------
		rem <TOKEN2> LocalAddress:port <TOKEN4> State
		rem ----------------------------------------------------
		if "%%b"=="LISTENING" goto TCP_LISTENING_LABEL
	)
	
	rem ---------------------------------------
	rem if here then we did not find the port
	rem ---------------------------------------
	echo result=success,port_RC=fail
	exit /b 0
	
:TCP_LISTENING_LABEL
	echo result=success,port_RC=success
	exit /b 0
)
